Gridspec-based colorbars can now be positioned above or to the left of the main axes
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

... by passing ``location="top"`` or ``location="left"`` to the ``colorbar()``
call.
